@@ -15,13 +15,13 @@ class TimeoutHTTPAdapter(HTTPAdapter):
         if "timeout" in kwargs:
             self.timeout = kwargs["timeout"]
             del kwargs["timeout"]
+
         super().__init__(*args, **kwargs)
 
     def send(self, request, **kwargs):
 
         timeout = kwargs.get("timeout")
-        if (
-            timeout is None
-        ):  # ensure that the default timeout is used if an explicit timeout is not provided.
+        if timeout is None:  # ensure that the default timeout is used if an explicit timeout is not provided.
             kwargs["timeout"] = self.timeout
+
         return super().send(request, **kwargs)
